@@ -92,6 +92,11 @@ struct nlist nl[] = {
 };
 
 
+#if SOLARIS >= 50700
+#define u16 uint16_t
+#define u32 uint32_t
+#endif
+
 static kvm_t *kd;
 
 
